﻿Type=Class
Version=3
@EndOfDesignText@
'Class module
Private Sub Class_Globals
	
	Private cCAB As CompactActionBar
	Private cAct As Activity
	Private HelpLbl As Label
	Private T As Timer
	Private HelpMap As Map
	Private IsAutoHide As Boolean
	Private HelpTextColor As Int = Colors.DarkGray
	Private HelpTextDismissColor As Int = Colors.Gray
End Sub

'Initializes the object and link the Help to an ActionBar
Public Sub Initialize(Act As Activity,CAB As CompactActionBar)

	cAct=Act
	cCAB=CAB
	'Initialise the timer that waits for autohide to finish
	T.Initialize("T",25)

	SetLabel
	'Store status of autohide
	Dim JO As JavaObject = cCAB
	IsAutoHide = JO.GetField("_isautohide")

End Sub
'Set Up Help Label Properties
Private Sub SetLabel
	
	

	HelpLbl.Initialize("HelpPanel")
	'Add the help panel, sized to match sizes used in CompactActionBar
	cAct.AddView(HelpLbl,65dip,60DIP,100%x-160dip,40dip)
	HelpLbl.TextSize= 12 * Density						'Simple scale so hopefully it's readable on all devices
	HelpLbl.Text = BuildRichString("Touch an icon for a description")
	SizeLabelHeight(HelpLbl)
	HelpLbl.Visible=False
	HelpLbl.Gravity=Gravity.TOP
	HelpMap.Initialize
	
	'Set Padding for help label
	Dim JO As JavaObject = HelpLbl
	JO.RunMethod("setPadding",Array As Object(2,2,2,2))
	
	'Set the gradient for help label
	SetLabelGradient( Colors.ARGB(255, 160, 160, 160),Colors.ARGB(255, 20, 20, 20),"TOP_BOTTOM")
	
End Sub
'Build the rich String for the help panel
Private Sub BuildRichString(HelpStr As String) As Object
	
	Dim RS As RichString
	RS.Initialize("{HTC}"&HelpStr&"{HTC}"&CRLF&CRLF&"{HDC}{RS}Touch to dismiss...{RS}{HDC}")
	RS.Color2(HelpTextColor,"{HTC}")
	RS.Color2(HelpTextDismissColor,"{HDC}")
	RS.RelativeSize2(0.75,"{RS}")
	Return RS
	
End Sub
Sub HelpTextColors(Textcolor As Int,DismissColor As Int)
	HelpTextColor=Textcolor
	HelpTextDismissColor=DismissColor
End Sub
'Add a help string for the icon at index
Sub AddHelp(HelpStr As String,Index As Int)
	HelpMap.Put(Index,HelpStr)
End Sub
'Set the gradient colors for the help label
'The possible orientations are:
' TOP_BOTTOM
' TR_BL (Top - Right To Bottom - Left)
' RIGHT_LEFT
' BR_TL (Bottom - Right To Top - Left
' BOTTOM_TOP
' BL_TR (Bottom - Left To Top - Left
' LEFT_RIGHT
' TL_BR (Top - Left To Bottom - Right)
Sub SetLabelGradient(Col1 As Int,Col2 As Int,Orientation As String)
	Dim gdwGradient As GradientDrawable
	Dim Cols(2) As Int
	Cols(0) = Col1
	Cols(1) = Col2
	gdwGradient.Initialize(Orientation, Cols)
	gdwGradient.CornerRadius = 10dip
	HelpLbl.Background = gdwGradient
End Sub
'Temporary fix for cut off icons
Sub SizeIconPanel(IconCount As Int)
	Dim JO As JavaObject = cCAB
	JO =JO.GetField("_iconspanel")
	JO = JO.RunMethod("getPanel",Null)
	JO.RunMethod("setWidth",Array As Object(IconCount*60dip))
End Sub
'Call this from the Click event sub of the related actionbar
'The sub will return true if it the touch is relevant to the help system
Sub ManageClick(ViewClicked As String, Value As Int) As Boolean
	'Return true if anything is done so the calling sub knows we've done something
	If HelpLbl.Visible Then
		If ViewClicked = "BarIcon" Then 
				HelpLbl.Text = BuildRichString(HelpMap.Get(Value))
				SizeLabelHeight(HelpLbl)
		End If
		'Turn off help
		If ViewClicked="Logo" Then HelpPanel_Click
		Return True
	End If
	'Turn on the help
	If ViewClicked="Logo" Then
		'You could also call help from a menu option if required
		Help
		Return True
	End If
	
End Sub
'Open/Close the ActionBar
Private Sub ToggleActionBar
	'Open.close the action bar
	Dim JO As JavaObject = cCAB
	JO.RunMethod("_pulltab_click",Null)
End Sub
'If we have two menus in one activity we need to turn one off to display the other
Sub ToggleVisibility

	Dim JO As JavaObject = cCAB
	JO = JO.GetField("_containerpanel")
	JO.RunMethod("setVisible",Array As Object((Not(JO.RunMethod("getVisible",Null)))))
	JO = cCAB
	JO = JO.GetField("_pulltab")
	JO.RunMethod("setVisible",Array As Object((Not(JO.RunMethod("getVisible",Null)))))

End Sub
'Turn on the help
Sub Help
	'Setup and display the help label
	HelpLbl.Text = BuildRichString("Touch an icon for a description")
	SizeLabelHeight(HelpLbl)
	HelpLbl.Visible=True
	'Disable the menu buttons
	'cCAB.MenuButtonEnabled(False)
	SetMenuButtonEnabled(False)
	'If the menu is autohidden, redisplay it when it's finished hiding
	If IsAutoHide Then T.Enabled=True
End Sub
Private Sub HelpPanel_Click
	'Turn of the help label
	HelpLbl.Visible=False
	'Set autohide back on if needed
	If IsAutoHide Then
		Dim JO As JavaObject = cCAB
		JO.SetField("_isautohide",True)
	End If
	'Enable the menu button for dropdown
	'cCAB.MenuButtonEnabled(True)
	SetMenuButtonEnabled(True)
	'Close the ActionBar
	ToggleActionBar

End Sub
'Timer to wait for hide to finish
Private Sub T_Tick
	'Need to wait until the animation is finished to reopen the menu
	Dim JO As JavaObject = cCAB
	Dim Moving As Boolean = JO.GetField("_animationstatus")
	'If it's still moving the wait some more
	If Moving Then Return
	'turn off the timer
	T.Enabled=False
	'Open the ActionBar
	ToggleActionBar
	'Autohide is on or we wouldn't be in here.
	'turn it off so it doesn't hide when asking for help
	Dim JO As JavaObject = cCAB
	JO.SetField("_isautohide",False)
	
End Sub
'Not currently used
Private Sub ToggleIcons(Enabled As Boolean)
	Dim JO As JavaObject = cCAB
	Dim icons() As Object=JO.GetField("_icons")
	'1st item is empty (not initialized)
	Dim Count As Int = 1
	'Get the string representation of the Icon
	Dim Str As String
	For i = 1 To icons.Length
		Dim Str As String = icons(i)
		If Str = "(Button) Not initialized" Then Exit
		cCAB.BarIconEnable(Count,Enabled)
		Count=Count+1
	Next
End Sub
'Get the relevant height for the label
Private Sub SizeLabelHeight(Lbl As Label)
	Dim STU As StringUtils
	Dim C As Canvas
	C.Initialize(cAct)
	Dim H As Int = STU.MeasureMultilineTextHeight(Lbl,Lbl.Text)
	HelpLbl.Height=H+4
	
End Sub
Sub SetMenuButtonEnabled(State As Boolean)
	Dim JO As JavaObject = cCAB
	JO.RunMethod("_setmenubuttonenabled",Array As Object(State))
End Sub